_internal library
This library exports the methods meant for use by generated code only, and not to be used directly.
Classes
- $JObject$Type$
- Double
- Represents a native 64 bit double in C.
- Int32
- Temporary fix for the macOS arm64 varargs problem.
- Int64
- Represents a native signed 64 bit integer in C.
- JGlobalReference
- A managed JNI global reference.
- JniResult
- Result type for use by JNI.
- JniVersionCheck
- JReference
-
NativeFunction<
T extends Function> - Represents a function type in C.
-
Pointer<
T extends NativeType> - Represents a pointer into the native C memory. Cannot be extended.
- RawReceivePort
- A low-level asynchronous message receiver.
- ReceivePort
- Together with SendPort, the only means of communication between isolates.
-
VarArgs<
T extends Record> - The types of variadic arguments passed in C.
- Void
- Represents a void type in C.
Extension Types
- JBuffer
- A container for data of a specific primitive type.
- JByteBuffer
- A byte JBuffer.
Extensions
- BoolToJava on bool
- DoubleToJava on double
- IntToJava on int
- JBooleanExtension on JBoolean
- JByteExtension on JByte
- JCharacterExtension on JCharacter
- JDoubleExtension on JDouble
- JFloatExtension on JFloat
- JIntegerExtension on JInteger
-
JIteratorToAdapter
on JIterator<
E> -
JListToAdapter
on JList<
E> - JLongExtension on JLong
-
JMapToAdapter
on JMap<
K, V> - JNumberExtension on JNumber
-
JSetToAdapter
on JSet<
E> - JShortExtension on JShort
- JStringExtension on JString
-
NativeFunctionPointer
on Pointer<
NativeFunction< NF> > - Extension on Pointer specialized for the type argument NativeFunction.
- NativePort on SendPort
-
Extension to retrieve the native
Dart_Portfrom a SendPort. -
ToJavaList
on Iterable<
E> -
ToJavaMap
on Map<
K, V> -
ToJavaSet
on Iterable<
E> - ToJStringMethod on String
- Uint8ListToJava on Uint8List
Constants
Properties
- jNullReference → JReference
-
final
-
nullptr
→ Pointer<
Never> -
Represents a pointer into the native C memory corresponding to 'NULL', e.g.
a pointer with address 0.
final
Typedefs
-
JFieldIDPtr
= Pointer<
jfieldID_> -
JMethodIDPtr
= Pointer<
jmethodID_> -
JObjectPtr
= Pointer<
Void> - Reference types, in C.
- JThrowablePtr = JObjectPtr