JBooleanArray class

Inheritance
Mixed-in types
Available extensions

Constructors

JBooleanArray(int length)
Creates a JBooleanArray of the given length.
factory
JBooleanArray.fromReference(JReference reference)
Construct a new JBooleanArray with reference as its underlying reference.

Properties

first bool
The first element.
no setterinherited
hashCode int
The hash code for this object.
no setterinherited
isEmpty bool
Whether this collection has no elements.
no setterinherited
isNotEmpty bool
Whether this collection has at least one element.
no setterinherited
isReleased bool
no setterinherited
iterator Iterator<bool>
A new Iterator that allows iterating the elements of this Iterable.
no setteroverride
jClass JClass
Returns JClass corresponding to concrete class of this object.
no setterinherited
last bool
The last element.
no setterinherited
length int
The number of elements in this array.
latefinal
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
single bool
Checks that this iterable has only one element, and returns that element.
no setterinherited

Methods

any(bool test(bool element)) bool
Checks whether any element of this iterable satisfies test.
inherited
as<T extends JObject?>(JType<T> type, {bool releaseOriginal = false}) → T
Casts this object to another type.
inherited
cast<R>() Iterable<R>
A view of this iterable as an iterable of R instances.
inherited
contains(Object? element) bool
Whether the collection contains an element equal to element.
inherited
elementAt(int index) bool
Returns the indexth element.
override
every(bool test(bool element)) bool
Checks whether every element of this iterable satisfies test.
inherited
expand<T>(Iterable<T> toElements(bool element)) Iterable<T>
Expands each element of this Iterable into zero or more elements.
inherited
firstWhere(bool test(bool element), {bool orElse()?}) bool
The first element that satisfies the given predicate test.
inherited
fold<T>(T initialValue, T combine(T previousValue, bool element)) → T
Reduces a collection to a single value by iteratively combining each element of the collection with an existing value
inherited
followedBy(Iterable<bool> other) Iterable<bool>
Creates the lazy concatenation of this iterable and other.
inherited
forEach(void action(bool element)) → void
Invokes action on each element of this iterable in iteration order.
inherited
getRange(int start, int end, {Allocator allocator = malloc}) Uint8List
isA<T extends JObject?>(JType<T> type) bool
Whether this object is of the given type ignoring the type parameters.
inherited
isInstanceOf(JClass jclass) bool
Whether this object is of the type of the given jclass.
inherited
join([String separator = ""]) String
Converts each element to a String and concatenates the strings.
inherited
lastWhere(bool test(bool element), {bool orElse()?}) bool
The last element that satisfies the given predicate test.
inherited
map<T>(T toElement(bool e)) Iterable<T>
The current elements of this iterable modified by toElement.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
reduce(bool combine(bool value, bool element)) bool
Reduces a collection to a single value by iteratively combining elements of the collection using the provided function.
inherited
release() → void
Releases the underlying reference.
inherited
releasedBy(Arena arena) → void
Registers this object to be released at the end of arena's lifetime.
inherited
setRange(int start, int end, Iterable<bool> iterable, [int skipCount = 0]) → void
singleWhere(bool test(bool element), {bool orElse()?}) bool
The single element that satisfies test.
inherited
skip(int count) Iterable<bool>
Creates an Iterable that provides all but the first count elements.
inherited
skipWhile(bool test(bool value)) Iterable<bool>
Creates an Iterable that skips leading elements while test is satisfied.
inherited
take(int count) Iterable<bool>
Creates a lazy iterable of the count first elements of this iterable.
inherited
takeWhile(bool test(bool value)) Iterable<bool>
Creates a lazy iterable of the leading elements satisfying test.
inherited
toList({bool growable = true}) List<bool>
Creates a List containing the elements of this Iterable.
inherited
toSet() Set<bool>
Creates a Set containing the same elements as this iterable.
inherited
toString() String
Returns a string representation of (some of) the elements of this.
inherited
use<R>(R callback(T)) → R

Available on T, provided by the JObjectUseExtension extension

Applies callback on this object and then delete the underlying JNI reference, returning the result of callback.
where(bool test(bool element)) Iterable<bool>
Creates a new lazy Iterable with all elements that satisfy the predicate test.
inherited
whereType<T>() Iterable<T>
Creates a new lazy Iterable with all elements that have type T.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited
operator [](int index) bool
operator []=(int index, bool value) → void

Constants

nullableType → const JType<JBooleanArray?>
The type which includes information such as the signature of this class.
type → const JType<JBooleanArray>
The type which includes information such as the signature of this class.