type constant
The type which includes information such as the signature of this class.
Implementation
static const JType<JByteArray> type = $JByteArray$Type$();
The type which includes information such as the signature of this class.
static const JType<JByteArray> type = $JByteArray$Type$();