JClass class
A high level wrapper over a JNI class reference.
JClasses are objects of type java.lang.Class.
- Inheritance
- Available extensions
Constructors
- JClass.forName(String name)
- Constructs a JClass associated with the class or interface with the given string name.
- JClass.fromReference(JReference reference)
-
Constructs a JClass with the underlying
reference.
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- isReleased → bool
-
no setterinherited
- jClass → JClass
-
Returns JClass corresponding to concrete class of this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
as<
T extends JObject> (JType< T> type, {bool releaseOriginal = false}) → T -
Casts this object to another
type.inherited -
constructorId(
String signature) → JConstructorId -
instanceFieldId(
String name, String signature) → JInstanceFieldId -
instanceMethodId(
String name, String signature) → JInstanceMethodId -
isA<
T extends JObject> (JType< T> type) → bool -
Whether this object is of the given
typeignoring the type parameters.inherited -
isInstanceOf(
JClass jclass) → bool -
Whether this object is of the type of the given
jclass.inherited -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
release(
) → void -
Releases the underlying
reference.inherited -
releasedBy(
Arena arena) → void -
Registers this object to be released at the end of
arena's lifetime.inherited -
staticFieldId(
String name, String signature) → JStaticFieldId -
staticMethodId(
String name, String signature) → JStaticMethodId -
toString(
) → String -
A string representation of this object.
inherited
-
use<
R> (R callback(T)) → R -
Available on T, provided by the JObjectUseExtension extension
Appliescallbackon this object and then delete the underlying JNI reference, returning the result ofcallback.
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited