JCollection<$E extends JObject?>
extension type
from: java.util.Collection
- on
- Implemented types
- Implementers
- Available extensions
Constructors
-
JCollection.implement($JCollection<
$E> $impl) -
factory
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- isReleased → bool
-
no setterinherited
- jClass → JClass
-
Returns JClass corresponding to concrete class of this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
add(
$E? object) → bool -
Available on JCollection<
from:$E> , provided by the JCollection$$Methods extensionpublic abstract boolean add(E object) -
addAll(
JCollection< $E?> ? collection) → bool -
Available on JCollection<
from:$E> , provided by the JCollection$$Methods extensionpublic abstract boolean addAll(java.util.Collection<? extends E> collection) -
as<
T extends JObject> (JType< T> type, {bool releaseOriginal = false}) → T -
Casts this object to another
type.inherited -
clear(
) → void -
Available on JCollection<
from:$E> , provided by the JCollection$$Methods extensionpublic abstract void clear() -
contains(
JObject? object) → bool -
Available on JCollection<
from:$E> , provided by the JCollection$$Methods extensionpublic abstract boolean contains(java.lang.Object object) -
containsAll(
JCollection< JObject?> ? collection) → bool -
Available on JCollection<
from:$E> , provided by the JCollection$$Methods extensionpublic abstract boolean containsAll(java.util.Collection<?> collection) -
equals(
JObject? object) → bool -
Available on JCollection<
from:$E> , provided by the JCollection$$Methods extensionpublic abstract boolean equals(java.lang.Object object) -
hashCode$1(
) → int -
Available on JCollection<
from:$E> , provided by the JCollection$$Methods extensionpublic abstract int hashCode() -
isA<
T extends JObject> (JType< T> type) → bool -
Whether this object is of the given
typeignoring the type parameters.inherited -
isEmpty(
) → bool -
Available on JCollection<
from:$E> , provided by the JCollection$$Methods extensionpublic abstract boolean isEmpty() -
isInstanceOf(
JClass jclass) → bool -
Whether this object is of the type of the given
jclass.inherited -
iterator(
) → JIterator< $E?> ? -
Available on JCollection<
from:$E> , provided by the JCollection$$Methods extensionpublic abstract java.util.Iterator<E> iterator()The returned object must be released after use, by calling the release method. -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
parallelStream(
) → JObject? -
Available on JCollection<
from:$E> , provided by the JCollection$$Methods extensionpublic java.util.stream.Stream<E> parallelStream()The returned object must be released after use, by calling the release method. -
release(
) → void -
Releases the underlying
reference.inherited -
releasedBy(
Arena arena) → void -
Registers this object to be released at the end of
arena's lifetime.inherited -
remove(
JObject? object) → bool -
Available on JCollection<
from:$E> , provided by the JCollection$$Methods extensionpublic abstract boolean remove(java.lang.Object object) -
removeAll(
JCollection< JObject?> ? collection) → bool -
Available on JCollection<
from:$E> , provided by the JCollection$$Methods extensionpublic abstract boolean removeAll(java.util.Collection<?> collection) -
removeIf(
JObject? predicate) → bool -
Available on JCollection<
from:$E> , provided by the JCollection$$Methods extensionpublic boolean removeIf(java.util.function.Predicate<? super E> predicate) -
retainAll(
JCollection< JObject?> ? collection) → bool -
Available on JCollection<
from:$E> , provided by the JCollection$$Methods extensionpublic abstract boolean retainAll(java.util.Collection<?> collection) -
size(
) → int -
Available on JCollection<
from:$E> , provided by the JCollection$$Methods extensionpublic abstract int size() -
spliterator(
) → JObject? -
Available on JCollection<
from:$E> , provided by the JCollection$$Methods extensionpublic java.util.Spliterator<E> spliterator()The returned object must be released after use, by calling the release method. -
stream(
) → JObject? -
Available on JCollection<
from:$E> , provided by the JCollection$$Methods extensionpublic java.util.stream.Stream<E> stream()The returned object must be released after use, by calling the release method. -
toArray(
) → JArray< JObject?> ? -
Available on JCollection<
from:$E> , provided by the JCollection$$Methods extensionpublic abstract java.lang.Object[] toArray()The returned object must be released after use, by calling the release method. -
toArray$1<
$T extends JObject?> (JObject? intFunction) → JArray< $T?> ? -
Available on JCollection<
from:$E> , provided by the JCollection$$Methods extensionpublic T[] toArray(java.util.function.IntFunction<T[]> intFunction)The returned object must be released after use, by calling the release method. -
toArray$2<
$T extends JObject?> (JArray< $T?> ? objects) → JArray<$T?> ? -
Available on JCollection<
from:$E> , provided by the JCollection$$Methods extensionpublic abstract T[] toArray(T[] objects)The returned object must be released after use, by calling the release method. -
toString(
) → String -
A string representation of this object.
inherited
-
use<
R> (R callback(T)) → R -
Available on T, provided by the JObjectUseExtension extension
Appliescallbackon this object and then delete the underlying JNI reference, returning the result ofcallback.
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Methods
-
implementIn<
$E extends JObject?> (JImplementer implementer, $JCollection< $E> $impl) → void
Constants
-
type
→ const JType<
JCollection< JObject?> > - The type which includes information such as the signature of this class.