JHashMap$$Methods<$K extends JObject?, $V extends JObject?> extension

on

Properties

isEmpty bool

Available on JHashMap<$K, $V>, provided by the JHashMap$$Methods extension

from: public boolean isEmpty()
no setter

Methods

clear() → void

Available on JHashMap<$K, $V>, provided by the JHashMap$$Methods extension

from: public void clear()
clone() JObject?

Available on JHashMap<$K, $V>, provided by the JHashMap$$Methods extension

from: public java.lang.Object clone() The returned object must be released after use, by calling the release method.
compute($K? object, JObject? biFunction) → $V?

Available on JHashMap<$K, $V>, provided by the JHashMap$$Methods extension

from: public V compute(K object, java.util.function.BiFunction<? super K, ? super V, ? extends V> biFunction) The returned object must be released after use, by calling the release method.
computeIfAbsent($K? object, JObject? function) → $V?

Available on JHashMap<$K, $V>, provided by the JHashMap$$Methods extension

from: public V computeIfAbsent(K object, java.util.function.Function<? super K, ? extends V> function) The returned object must be released after use, by calling the release method.
computeIfPresent($K? object, JObject? biFunction) → $V?

Available on JHashMap<$K, $V>, provided by the JHashMap$$Methods extension

from: public V computeIfPresent(K object, java.util.function.BiFunction<? super K, ? super V, ? extends V> biFunction) The returned object must be released after use, by calling the release method.
containsKey(JObject? object) bool

Available on JHashMap<$K, $V>, provided by the JHashMap$$Methods extension

from: public boolean containsKey(java.lang.Object object)
containsValue(JObject? object) bool

Available on JHashMap<$K, $V>, provided by the JHashMap$$Methods extension

from: public boolean containsValue(java.lang.Object object)
entrySet() JSet<JMap$JEntry<$K?, $V?>?>?

Available on JHashMap<$K, $V>, provided by the JHashMap$$Methods extension

from: public java.util.Set<java.util.Map$Entry<K, V>> entrySet() The returned object must be released after use, by calling the release method.
equals(JObject? object) bool

Available on JHashMap<$K, $V>, provided by the JHashMap$$Methods extension

from: public abstract boolean equals(java.lang.Object object)
forEach(JObject? biConsumer) → void

Available on JHashMap<$K, $V>, provided by the JHashMap$$Methods extension

from: public void forEach(java.util.function.BiConsumer<? super K, ? super V> biConsumer)
get(JObject? object) → $V?

Available on JHashMap<$K, $V>, provided by the JHashMap$$Methods extension

from: public V get(java.lang.Object object) The returned object must be released after use, by calling the release method.
getOrDefault(JObject? object, $V? object1) → $V?

Available on JHashMap<$K, $V>, provided by the JHashMap$$Methods extension

from: public V getOrDefault(java.lang.Object object, V object1) The returned object must be released after use, by calling the release method.
hashCode$1() int

Available on JHashMap<$K, $V>, provided by the JHashMap$$Methods extension

from: public abstract int hashCode()
keySet() JSet<$K?>?

Available on JHashMap<$K, $V>, provided by the JHashMap$$Methods extension

from: public java.util.Set<K> keySet() The returned object must be released after use, by calling the release method.
merge($K? object, $V? object1, JObject? biFunction) → $V?

Available on JHashMap<$K, $V>, provided by the JHashMap$$Methods extension

from: public V merge(K object, V object1, java.util.function.BiFunction<? super V, ? super V, ? extends V> biFunction) The returned object must be released after use, by calling the release method.
put($K? object, $V? object1) → $V?

Available on JHashMap<$K, $V>, provided by the JHashMap$$Methods extension

from: public V put(K object, V object1) The returned object must be released after use, by calling the release method.
putAll(JMap<$K?, $V?>? map) → void

Available on JHashMap<$K, $V>, provided by the JHashMap$$Methods extension

from: public void putAll(java.util.Map<? extends K, ? extends V> map)
putIfAbsent($K? object, $V? object1) → $V?

Available on JHashMap<$K, $V>, provided by the JHashMap$$Methods extension

from: public V putIfAbsent(K object, V object1) The returned object must be released after use, by calling the release method.
remove(JObject? object) → $V?

Available on JHashMap<$K, $V>, provided by the JHashMap$$Methods extension

from: public V remove(java.lang.Object object) The returned object must be released after use, by calling the release method.
remove$1(JObject? object, JObject? object1) bool

Available on JHashMap<$K, $V>, provided by the JHashMap$$Methods extension

from: public boolean remove(java.lang.Object object, java.lang.Object object1)
replace($K? object, $V? object1) → $V?

Available on JHashMap<$K, $V>, provided by the JHashMap$$Methods extension

from: public V replace(K object, V object1) The returned object must be released after use, by calling the release method.
replace$1($K? object, $V? object1, $V? object2) bool

Available on JHashMap<$K, $V>, provided by the JHashMap$$Methods extension

from: public boolean replace(K object, V object1, V object2)
replaceAll(JObject? biFunction) → void

Available on JHashMap<$K, $V>, provided by the JHashMap$$Methods extension

from: public void replaceAll(java.util.function.BiFunction<? super K, ? super V, ? extends V> biFunction)
size() int

Available on JHashMap<$K, $V>, provided by the JHashMap$$Methods extension

from: public int size()
values() JCollection<$V?>?

Available on JHashMap<$K, $V>, provided by the JHashMap$$Methods extension

from: public java.util.Collection<V> values() The returned object must be released after use, by calling the release method.