JMap<$K extends JObject?, $V extends JObject?>
extension type
from: java.util.Map
- on
- Implemented types
- Implementers
- Available extensions
Constructors
-
JMap.implement($JMap<
$K, $V> $impl) -
factory
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- isReleased → bool
-
no setterinherited
- jClass → JClass
-
Returns JClass corresponding to concrete class of this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
as<
T extends JObject> (JType< T> type, {bool releaseOriginal = false}) → T -
Casts this object to another
type.inherited -
asDart(
) → Map< K, V> -
Available on JMap<
Wraps this JMap in an adapter that implements an immutable Map.K, V> , provided by the JMapToAdapter extension -
clear(
) → void -
Available on JMap<
from:$K, $V> , provided by the JMap$$Methods extensionpublic abstract void clear() -
compute(
$K? object, JObject? biFunction) → $V? -
Available on JMap<
from:$K, $V> , provided by the JMap$$Methods extensionpublic V compute(K object, java.util.function.BiFunction<? super K, ? super V, ? extends V> biFunction)The returned object must be released after use, by calling the release method. -
computeIfAbsent(
$K? object, JObject? function) → $V? -
Available on JMap<
from:$K, $V> , provided by the JMap$$Methods extensionpublic V computeIfAbsent(K object, java.util.function.Function<? super K, ? extends V> function)The returned object must be released after use, by calling the release method. -
computeIfPresent(
$K? object, JObject? biFunction) → $V? -
Available on JMap<
from:$K, $V> , provided by the JMap$$Methods extensionpublic V computeIfPresent(K object, java.util.function.BiFunction<? super K, ? super V, ? extends V> biFunction)The returned object must be released after use, by calling the release method. -
containsKey(
JObject? object) → bool -
Available on JMap<
from:$K, $V> , provided by the JMap$$Methods extensionpublic abstract boolean containsKey(java.lang.Object object) -
containsValue(
JObject? object) → bool -
Available on JMap<
from:$K, $V> , provided by the JMap$$Methods extensionpublic abstract boolean containsValue(java.lang.Object object) -
entrySet(
) → JSet< JMap$JEntry< ?$K?, $V?> ?> -
Available on JMap<
from:$K, $V> , provided by the JMap$$Methods extensionpublic abstract java.util.Set<java.util.Map$Entry<K, V>> entrySet()The returned object must be released after use, by calling the release method. -
equals(
JObject? object) → bool -
Available on JMap<
from:$K, $V> , provided by the JMap$$Methods extensionpublic abstract boolean equals(java.lang.Object object) -
forEach(
JObject? biConsumer) → void -
Available on JMap<
from:$K, $V> , provided by the JMap$$Methods extensionpublic void forEach(java.util.function.BiConsumer<? super K, ? super V> biConsumer) -
get(
JObject? object) → $V? -
Available on JMap<
from:$K, $V> , provided by the JMap$$Methods extensionpublic abstract V get(java.lang.Object object)The returned object must be released after use, by calling the release method. -
getOrDefault(
JObject? object, $V? object1) → $V? -
Available on JMap<
from:$K, $V> , provided by the JMap$$Methods extensionpublic V getOrDefault(java.lang.Object object, V object1)The returned object must be released after use, by calling the release method. -
hashCode$1(
) → int -
Available on JMap<
from:$K, $V> , provided by the JMap$$Methods extensionpublic abstract int hashCode() -
isA<
T extends JObject> (JType< T> type) → bool -
Whether this object is of the given
typeignoring the type parameters.inherited -
isEmpty(
) → bool -
Available on JMap<
from:$K, $V> , provided by the JMap$$Methods extensionpublic abstract boolean isEmpty() -
isInstanceOf(
JClass jclass) → bool -
Whether this object is of the type of the given
jclass.inherited -
keySet(
) → JSet< $K?> ? -
Available on JMap<
from:$K, $V> , provided by the JMap$$Methods extensionpublic abstract java.util.Set<K> keySet()The returned object must be released after use, by calling the release method. -
merge(
$K? object, $V? object1, JObject? biFunction) → $V? -
Available on JMap<
from:$K, $V> , provided by the JMap$$Methods extensionpublic V merge(K object, V object1, java.util.function.BiFunction<? super V, ? super V, ? extends V> biFunction)The returned object must be released after use, by calling the release method. -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
put(
$K? object, $V? object1) → $V? -
Available on JMap<
from:$K, $V> , provided by the JMap$$Methods extensionpublic abstract V put(K object, V object1)The returned object must be released after use, by calling the release method. -
putAll(
JMap< $K?, $V?> ? map) → void -
Available on JMap<
from:$K, $V> , provided by the JMap$$Methods extensionpublic abstract void putAll(java.util.Map<? extends K, ? extends V> map) -
putIfAbsent(
$K? object, $V? object1) → $V? -
Available on JMap<
from:$K, $V> , provided by the JMap$$Methods extensionpublic V putIfAbsent(K object, V object1)The returned object must be released after use, by calling the release method. -
release(
) → void -
Releases the underlying
reference.inherited -
releasedBy(
Arena arena) → void -
Registers this object to be released at the end of
arena's lifetime.inherited -
remove(
JObject? object) → $V? -
Available on JMap<
from:$K, $V> , provided by the JMap$$Methods extensionpublic abstract V remove(java.lang.Object object)The returned object must be released after use, by calling the release method. -
remove$1(
JObject? object, JObject? object1) → bool -
Available on JMap<
from:$K, $V> , provided by the JMap$$Methods extensionpublic boolean remove(java.lang.Object object, java.lang.Object object1) -
replace(
$K? object, $V? object1) → $V? -
Available on JMap<
from:$K, $V> , provided by the JMap$$Methods extensionpublic V replace(K object, V object1)The returned object must be released after use, by calling the release method. -
replace$1(
$K? object, $V? object1, $V? object2) → bool -
Available on JMap<
from:$K, $V> , provided by the JMap$$Methods extensionpublic boolean replace(K object, V object1, V object2) -
replaceAll(
JObject? biFunction) → void -
Available on JMap<
from:$K, $V> , provided by the JMap$$Methods extensionpublic void replaceAll(java.util.function.BiFunction<? super K, ? super V, ? extends V> biFunction) -
size(
) → int -
Available on JMap<
from:$K, $V> , provided by the JMap$$Methods extensionpublic abstract int size() -
toString(
) → String -
A string representation of this object.
inherited
-
use<
R> (R callback(T)) → R -
Available on T, provided by the JObjectUseExtension extension
Appliescallbackon this object and then delete the underlying JNI reference, returning the result ofcallback. -
values(
) → JCollection< $V?> ? -
Available on JMap<
from:$K, $V> , provided by the JMap$$Methods extensionpublic abstract java.util.Collection<V> values()The returned object must be released after use, by calling the release method.
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Methods
-
copyOf<
$K extends JObject?, $V extends JObject?> (JMap< $K?, $V?> ? map) → JMap<$K?, $V?> ? -
from:
static public java.util.Map<K, V> copyOf(java.util.Map<? extends K, ? extends V> map)The returned object must be released after use, by calling the release method. -
entry<
$K extends JObject?, $V extends JObject?> ($K? object, $V? object1) → JMap$JEntry< $K?, $V?> ? -
from:
static public java.util.Map$Entry<K, V> entry(K object, V object1)The returned object must be released after use, by calling the release method. -
implementIn<
$K extends JObject?, $V extends JObject?> (JImplementer implementer, $JMap< $K, $V> $impl) → void -
of<
$K extends JObject?, $V extends JObject?> () → JMap< $K?, $V?> ? -
from:
static public java.util.Map<K, V> of()The returned object must be released after use, by calling the release method. -
of$1<
$K extends JObject?, $V extends JObject?> ($K? object, $V? object1) → JMap< $K?, $V?> ? -
from:
static public java.util.Map<K, V> of(K object, V object1)The returned object must be released after use, by calling the release method. -
of$10<
$K extends JObject?, $V extends JObject?> ($K? object, $V? object1, $K? object2, $V? object3, $K? object4, $V? object5, $K? object6, $V? object7, $K? object8, $V? object9, $K? object10, $V? object11, $K? object12, $V? object13, $K? object14, $V? object15, $K? object16, $V? object17, $K? object18, $V? object19) → JMap< $K?, $V?> ? -
from:
static public java.util.Map<K, V> of(K object, V object1, K object2, V object3, K object4, V object5, K object6, V object7, K object8, V object9, K object10, V object11, K object12, V object13, K object14, V object15, K object16, V object17, K object18, V object19)The returned object must be released after use, by calling the release method. -
of$2<
$K extends JObject?, $V extends JObject?> ($K? object, $V? object1, $K? object2, $V? object3) → JMap< $K?, $V?> ? -
from:
static public java.util.Map<K, V> of(K object, V object1, K object2, V object3)The returned object must be released after use, by calling the release method. -
of$3<
$K extends JObject?, $V extends JObject?> ($K? object, $V? object1, $K? object2, $V? object3, $K? object4, $V? object5) → JMap< $K?, $V?> ? -
from:
static public java.util.Map<K, V> of(K object, V object1, K object2, V object3, K object4, V object5)The returned object must be released after use, by calling the release method. -
of$4<
$K extends JObject?, $V extends JObject?> ($K? object, $V? object1, $K? object2, $V? object3, $K? object4, $V? object5, $K? object6, $V? object7) → JMap< $K?, $V?> ? -
from:
static public java.util.Map<K, V> of(K object, V object1, K object2, V object3, K object4, V object5, K object6, V object7)The returned object must be released after use, by calling the release method. -
of$5<
$K extends JObject?, $V extends JObject?> ($K? object, $V? object1, $K? object2, $V? object3, $K? object4, $V? object5, $K? object6, $V? object7, $K? object8, $V? object9) → JMap< $K?, $V?> ? -
from:
static public java.util.Map<K, V> of(K object, V object1, K object2, V object3, K object4, V object5, K object6, V object7, K object8, V object9)The returned object must be released after use, by calling the release method. -
of$6<
$K extends JObject?, $V extends JObject?> ($K? object, $V? object1, $K? object2, $V? object3, $K? object4, $V? object5, $K? object6, $V? object7, $K? object8, $V? object9, $K? object10, $V? object11) → JMap< $K?, $V?> ? -
from:
static public java.util.Map<K, V> of(K object, V object1, K object2, V object3, K object4, V object5, K object6, V object7, K object8, V object9, K object10, V object11)The returned object must be released after use, by calling the release method. -
of$7<
$K extends JObject?, $V extends JObject?> ($K? object, $V? object1, $K? object2, $V? object3, $K? object4, $V? object5, $K? object6, $V? object7, $K? object8, $V? object9, $K? object10, $V? object11, $K? object12, $V? object13) → JMap< $K?, $V?> ? -
from:
static public java.util.Map<K, V> of(K object, V object1, K object2, V object3, K object4, V object5, K object6, V object7, K object8, V object9, K object10, V object11, K object12, V object13)The returned object must be released after use, by calling the release method. -
of$8<
$K extends JObject?, $V extends JObject?> ($K? object, $V? object1, $K? object2, $V? object3, $K? object4, $V? object5, $K? object6, $V? object7, $K? object8, $V? object9, $K? object10, $V? object11, $K? object12, $V? object13, $K? object14, $V? object15) → JMap< $K?, $V?> ? -
from:
static public java.util.Map<K, V> of(K object, V object1, K object2, V object3, K object4, V object5, K object6, V object7, K object8, V object9, K object10, V object11, K object12, V object13, K object14, V object15)The returned object must be released after use, by calling the release method. -
of$9<
$K extends JObject?, $V extends JObject?> ($K? object, $V? object1, $K? object2, $V? object3, $K? object4, $V? object5, $K? object6, $V? object7, $K? object8, $V? object9, $K? object10, $V? object11, $K? object12, $V? object13, $K? object14, $V? object15, $K? object16, $V? object17) → JMap< $K?, $V?> ? -
from:
static public java.util.Map<K, V> of(K object, V object1, K object2, V object3, K object4, V object5, K object6, V object7, K object8, V object9, K object10, V object11, K object12, V object13, K object14, V object15, K object16, V object17)The returned object must be released after use, by calling the release method. -
ofEntries<
$K extends JObject?, $V extends JObject?> (JArray< JMap$JEntry< ? entrys) → JMap<$K?, $V?> ?>$K?, $V?> ? -
from:
static public java.util.Map<K, V> ofEntries(java.util.Map$Entry[] entrys)The returned object must be released after use, by calling the release method.