JObject class

A high-level wrapper for JNI global object reference.

This is the base class for classes generated by jnigen.

Implementers
Available extensions

Constructors

JObject.fromReference(JReference reference)
Constructs a JObject with the underlying reference.

Properties

hashCode int
The hash code for this object.
no setteroverride
isReleased bool
no setter
jClass JClass
Returns JClass corresponding to concrete class of this object.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

as<T extends JObject>(JType<T> type, {bool releaseOriginal = false}) → T
Casts this object to another type.
isA<T extends JObject>(JType<T> type) bool
Whether this object is of the given type ignoring the type parameters.
isInstanceOf(JClass jclass) bool
Whether this object is of the type of the given jclass.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
release() → void
Releases the underlying reference.
releasedBy(Arena arena) → void
Registers this object to be released at the end of arena's lifetime.
toString() String
A string representation of this object.
override
use<R>(R callback(T)) → R

Available on T, provided by the JObjectUseExtension extension

Applies callback on this object and then delete the underlying JNI reference, returning the result of callback.

Operators

operator ==(Object other) bool
The equality operator.
override

Constants

type → const JType<JObject>
The type which includes information such as the signature of this class.