JReference class abstract final

An abstract reference to a Java object managed by JNI.

Implemented types
Implementers

Properties

hashCode → int
The hash code for this object.
no setterinherited
isNull → bool
Whether the underlying JNI reference is null or not.
no setter
isReleased → bool
Whether the underlying JNI reference is deleted or not.
no setter
pointer → JObjectPtr
The underlying JNI reference.
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
release() → void
Deletes the underlying JNI reference and marks this as released.
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited