JSet<$E extends JObject?> extension type

from: java.util.Set

on
Implemented types
Implementers
Available extensions

Constructors

JSet.implement($JSet<$E> $impl)
factory

Properties

hashCode int
The hash code for this object.
no setterinherited
isReleased bool
no setterinherited
jClass JClass
Returns JClass corresponding to concrete class of this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

add($E? object) bool

Available on JCollection<$E>, provided by the JCollection$$Methods extension

from: public abstract boolean add(E object)
add($E? object) bool

Available on JSet<$E>, provided by the JSet$$Methods extension

from: public abstract boolean add(E object)
addAll(JCollection<$E?>? collection) bool

Available on JCollection<$E>, provided by the JCollection$$Methods extension

from: public abstract boolean addAll(java.util.Collection<? extends E> collection)
addAll(JCollection<$E?>? collection) bool

Available on JSet<$E>, provided by the JSet$$Methods extension

from: public abstract boolean addAll(java.util.Collection<? extends E> collection)
as<T extends JObject>(JType<T> type, {bool releaseOriginal = false}) → T
Casts this object to another type.
inherited
asDart() Set<E>

Available on JSet<E>, provided by the JSetToAdapter extension

Wraps this JSet in an adapter that implements a Set.
clear() → void

Available on JCollection<$E>, provided by the JCollection$$Methods extension

from: public abstract void clear()
clear() → void

Available on JSet<$E>, provided by the JSet$$Methods extension

from: public abstract void clear()
contains(JObject? object) bool

Available on JCollection<$E>, provided by the JCollection$$Methods extension

from: public abstract boolean contains(java.lang.Object object)
contains(JObject? object) bool

Available on JSet<$E>, provided by the JSet$$Methods extension

from: public abstract boolean contains(java.lang.Object object)
containsAll(JCollection<JObject?>? collection) bool

Available on JSet<$E>, provided by the JSet$$Methods extension

from: public abstract boolean containsAll(java.util.Collection<?> collection)
containsAll(JCollection<JObject?>? collection) bool

Available on JCollection<$E>, provided by the JCollection$$Methods extension

from: public abstract boolean containsAll(java.util.Collection<?> collection)
equals(JObject? object) bool

Available on JCollection<$E>, provided by the JCollection$$Methods extension

from: public abstract boolean equals(java.lang.Object object)
equals(JObject? object) bool

Available on JSet<$E>, provided by the JSet$$Methods extension

from: public abstract boolean equals(java.lang.Object object)
hashCode$1() int

Available on JCollection<$E>, provided by the JCollection$$Methods extension

from: public abstract int hashCode()
hashCode$1() int

Available on JSet<$E>, provided by the JSet$$Methods extension

from: public abstract int hashCode()
isA<T extends JObject>(JType<T> type) bool
Whether this object is of the given type ignoring the type parameters.
inherited
isEmpty() bool

Available on JCollection<$E>, provided by the JCollection$$Methods extension

from: public abstract boolean isEmpty()
isEmpty() bool

Available on JSet<$E>, provided by the JSet$$Methods extension

from: public abstract boolean isEmpty()
isInstanceOf(JClass jclass) bool
Whether this object is of the type of the given jclass.
inherited
iterator() JIterator<$E?>?

Available on JCollection<$E>, provided by the JCollection$$Methods extension

from: public abstract java.util.Iterator<E> iterator() The returned object must be released after use, by calling the release method.
iterator() JIterator<$E?>?

Available on JSet<$E>, provided by the JSet$$Methods extension

from: public abstract java.util.Iterator<E> iterator() The returned object must be released after use, by calling the release method.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
parallelStream() JObject?

Available on JSet<$E>, provided by the JSet$$Methods extension

from: public java.util.stream.Stream<E> parallelStream() The returned object must be released after use, by calling the release method.
parallelStream() JObject?

Available on JCollection<$E>, provided by the JCollection$$Methods extension

from: public java.util.stream.Stream<E> parallelStream() The returned object must be released after use, by calling the release method.
release() → void
Releases the underlying reference.
inherited
releasedBy(Arena arena) → void
Registers this object to be released at the end of arena's lifetime.
inherited
remove(JObject? object) bool

Available on JCollection<$E>, provided by the JCollection$$Methods extension

from: public abstract boolean remove(java.lang.Object object)
remove(JObject? object) bool

Available on JSet<$E>, provided by the JSet$$Methods extension

from: public abstract boolean remove(java.lang.Object object)
removeAll(JCollection<JObject?>? collection) bool

Available on JCollection<$E>, provided by the JCollection$$Methods extension

from: public abstract boolean removeAll(java.util.Collection<?> collection)
removeAll(JCollection<JObject?>? collection) bool

Available on JSet<$E>, provided by the JSet$$Methods extension

from: public abstract boolean removeAll(java.util.Collection<?> collection)
removeIf(JObject? predicate) bool

Available on JCollection<$E>, provided by the JCollection$$Methods extension

from: public boolean removeIf(java.util.function.Predicate<? super E> predicate)
removeIf(JObject? predicate) bool

Available on JSet<$E>, provided by the JSet$$Methods extension

from: public boolean removeIf(java.util.function.Predicate<? super E> predicate)
retainAll(JCollection<JObject?>? collection) bool

Available on JCollection<$E>, provided by the JCollection$$Methods extension

from: public abstract boolean retainAll(java.util.Collection<?> collection)
retainAll(JCollection<JObject?>? collection) bool

Available on JSet<$E>, provided by the JSet$$Methods extension

from: public abstract boolean retainAll(java.util.Collection<?> collection)
size() int

Available on JCollection<$E>, provided by the JCollection$$Methods extension

from: public abstract int size()
size() int

Available on JSet<$E>, provided by the JSet$$Methods extension

from: public abstract int size()
spliterator() JObject?

Available on JSet<$E>, provided by the JSet$$Methods extension

from: public java.util.Spliterator<E> spliterator() The returned object must be released after use, by calling the release method.
spliterator() JObject?

Available on JCollection<$E>, provided by the JCollection$$Methods extension

from: public java.util.Spliterator<E> spliterator() The returned object must be released after use, by calling the release method.
stream() JObject?

Available on JCollection<$E>, provided by the JCollection$$Methods extension

from: public java.util.stream.Stream<E> stream() The returned object must be released after use, by calling the release method.
stream() JObject?

Available on JSet<$E>, provided by the JSet$$Methods extension

from: public java.util.stream.Stream<E> stream() The returned object must be released after use, by calling the release method.
toArray() JArray<JObject?>?

Available on JCollection<$E>, provided by the JCollection$$Methods extension

from: public abstract java.lang.Object[] toArray() The returned object must be released after use, by calling the release method.
toArray() JArray<JObject?>?

Available on JSet<$E>, provided by the JSet$$Methods extension

from: public abstract java.lang.Object[] toArray() The returned object must be released after use, by calling the release method.
toArray$1<$T extends JObject?>(JObject? intFunction) JArray<$T?>?

Available on JCollection<$E>, provided by the JCollection$$Methods extension

from: public T[] toArray(java.util.function.IntFunction<T[]> intFunction) The returned object must be released after use, by calling the release method.
toArray$1<$T extends JObject?>(JArray<$T?>? objects) JArray<$T?>?

Available on JSet<$E>, provided by the JSet$$Methods extension

from: public abstract T[] toArray(T[] objects) The returned object must be released after use, by calling the release method.
toArray$2<$T extends JObject?>(JArray<$T?>? objects) JArray<$T?>?

Available on JCollection<$E>, provided by the JCollection$$Methods extension

from: public abstract T[] toArray(T[] objects) The returned object must be released after use, by calling the release method.
toArray$2<$T extends JObject?>(JObject? intFunction) JArray<$T?>?

Available on JSet<$E>, provided by the JSet$$Methods extension

from: public T[] toArray(java.util.function.IntFunction<T[]> intFunction) The returned object must be released after use, by calling the release method.
toString() String
A string representation of this object.
inherited
use<R>(R callback(T)) → R

Available on T, provided by the JObjectUseExtension extension

Applies callback on this object and then delete the underlying JNI reference, returning the result of callback.

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

copyOf<$E extends JObject?>(JCollection<$E?>? collection) JSet<$E?>?
from: static public java.util.Set<E> copyOf(java.util.Collection<? extends E> collection) The returned object must be released after use, by calling the release method.
implementIn<$E extends JObject?>(JImplementer implementer, $JSet<$E> $impl) → void
of<$E extends JObject?>() JSet<$E?>?
from: static public java.util.Set<E> of() The returned object must be released after use, by calling the release method.
of$1<$E extends JObject?>($E? object) JSet<$E?>?
from: static public java.util.Set<E> of(E object) The returned object must be released after use, by calling the release method.
of$10<$E extends JObject?>($E? object, $E? object1, $E? object2, $E? object3, $E? object4, $E? object5, $E? object6, $E? object7, $E? object8, $E? object9) JSet<$E?>?
from: static public java.util.Set<E> of(E object, E object1, E object2, E object3, E object4, E object5, E object6, E object7, E object8, E object9) The returned object must be released after use, by calling the release method.
of$11<$E extends JObject?>(JArray<$E?>? objects) JSet<$E?>?
from: static public java.util.Set<E> of(E[] objects) The returned object must be released after use, by calling the release method.
of$2<$E extends JObject?>($E? object, $E? object1) JSet<$E?>?
from: static public java.util.Set<E> of(E object, E object1) The returned object must be released after use, by calling the release method.
of$3<$E extends JObject?>($E? object, $E? object1, $E? object2) JSet<$E?>?
from: static public java.util.Set<E> of(E object, E object1, E object2) The returned object must be released after use, by calling the release method.
of$4<$E extends JObject?>($E? object, $E? object1, $E? object2, $E? object3) JSet<$E?>?
from: static public java.util.Set<E> of(E object, E object1, E object2, E object3) The returned object must be released after use, by calling the release method.
of$5<$E extends JObject?>($E? object, $E? object1, $E? object2, $E? object3, $E? object4) JSet<$E?>?
from: static public java.util.Set<E> of(E object, E object1, E object2, E object3, E object4) The returned object must be released after use, by calling the release method.
of$6<$E extends JObject?>($E? object, $E? object1, $E? object2, $E? object3, $E? object4, $E? object5) JSet<$E?>?
from: static public java.util.Set<E> of(E object, E object1, E object2, E object3, E object4, E object5) The returned object must be released after use, by calling the release method.
of$7<$E extends JObject?>($E? object, $E? object1, $E? object2, $E? object3, $E? object4, $E? object5, $E? object6) JSet<$E?>?
from: static public java.util.Set<E> of(E object, E object1, E object2, E object3, E object4, E object5, E object6) The returned object must be released after use, by calling the release method.
of$8<$E extends JObject?>($E? object, $E? object1, $E? object2, $E? object3, $E? object4, $E? object5, $E? object6, $E? object7) JSet<$E?>?
from: static public java.util.Set<E> of(E object, E object1, E object2, E object3, E object4, E object5, E object6, E object7) The returned object must be released after use, by calling the release method.
of$9<$E extends JObject?>($E? object, $E? object1, $E? object2, $E? object3, $E? object4, $E? object5, $E? object6, $E? object7, $E? object8) JSet<$E?>?
from: static public java.util.Set<E> of(E object, E object1, E object2, E object3, E object4, E object5, E object6, E object7, E object8) The returned object must be released after use, by calling the release method.

Constants

type → const JType<JSet<JObject?>>
The type which includes information such as the signature of this class.