_internal library

This library exports the methods meant for use by generated code only, and not to be used directly.

Classes

Double
Represents a native 64 bit double in C.
Int32
Temporary fix for the macOS arm64 varargs problem.
Int64
Represents a native signed 64 bit integer in C.
JGlobalReference
A managed JNI global reference.
JniResult
Result type for use by JNI.
JReference
NativeFunction<T extends Function>
Represents a function type in C.
Pointer<T extends NativeType>
Represents a pointer into the native C memory. Cannot be extended.
RawReceivePort
A low-level asynchronous message receiver.
ReceivePort
Together with SendPort, the only means of communication between isolates.
VarArgs<T extends Record>
The types of variadic arguments passed in C.
Void
Represents a void type in C.

Extensions

NativeFunctionPointer on Pointer<NativeFunction<NF>>
Extension on Pointer specialized for the type argument NativeFunction.
NativePort on SendPort
Extension to retrieve the native Dart_Port from a SendPort.

Constants

internal → const Object
Annotation on declaration that should not be used outside of its package.

Properties

jNullReference JReference
final
nullptr Pointer<Never>
Represents a pointer into the native C memory corresponding to 'NULL', e.g. a pointer with address 0.
final

Typedefs

JFieldIDPtr = Pointer<jfieldID_>
JMethodIDPtr = Pointer<jmethodID_>
JObjectPtr = Pointer<Void>
Reference types, in C.
JThrowablePtr = JObjectPtr