JIterator<$E extends JObject?> class
- Inheritance
- Implemented types
-
- Iterator<
$E>
- Iterator<
- Available extensions
Constructors
-
JIterator.fromReference(JType<
$E> E, JReference reference)
Properties
- current → $E
-
The current element.
no setteroverride
- hashCode → int
-
The hash code for this object.
no setterinherited
- isReleased → bool
-
no setterinherited
- jClass → JClass
-
Returns JClass corresponding to concrete class of this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
as<
T extends JObject?> (JType< T> type, {bool releaseOriginal = false}) → T -
Casts this object to another
type.inherited -
isA<
T extends JObject?> (JType< T> type) → bool -
Whether this object is of the given
typeignoring the type parameters.inherited -
isInstanceOf(
JClass jclass) → bool -
Whether this object is of the type of the given
jclass.inherited -
moveNext(
) → bool -
Advances the iterator to the next element of the iteration.
override
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
release(
) → void -
Releases the underlying
reference.inherited -
releasedBy(
Arena arena) → void -
Registers this object to be released at the end of
arena's lifetime.inherited -
toString(
) → String -
A string representation of this object.
inherited
-
use<
R> (R callback(T)) → R -
Available on T, provided by the JObjectUseExtension extension
Appliescallbackon this object and then delete the underlying JNI reference, returning the result ofcallback.
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited